﻿var Translation = {
"places.Country100":"Izland",
"places.Country101":"India",
"places.Country102":"Indonézia",
"places.Country103":"Irán",
"places.ROOMS":"Szobák",
"places.Country104":"Irak",
"mapPlayer_15_buttonsArray_settings_buttonLabel":"Több…",
"nokia.maps.pfw.turn.roundabout10":"hajts ki a 10. kijáraton",
"places.Country105":"Írország",
"nokia.maps.pfw.turn.roundabout11":"hajts ki a 11. kijáraton",
"places.Country106":"Isle of Man",
"nokia.maps.pfw.turn.roundabout12":"hajts ki a 12. kijáraton",
"places.Country107":"Izrael",
"places.Country108":"Olaszország",
"places.Country109":"Jamaika",
"mapPlayer_8_about_Ovi_txt":"Többet az Ovi Maps-ról",
"nokia.maps.pfw.action.enterhighwayfromleft":"hajts fel az autópályára balról",
"nokia.maps.pfw.action.undefined":"utazás indítása",
"places.Country110":"Japán",
"places.Country111":"Jersey",
"places.Country112":"Jordánia",
"nokia.maps.pfw.action.end":"megérkeztél az uticélhoz",
"places.Country113":"Kazakhstán",
"places.Country114":"Kenya",
"places.Country115":"Kiribati",
"nokia.maps.pfw.action.roundabout":"a körforgalomnál",
"places.Country116":"Koreai NDK",
"places.Country117":"Korea",
"places.Country118":"Kuwait",
"places.Country119":"Kyrgyzstan",
"nokia.maps.pfw.spices.routesettingsspice.allowedroutetype":"Engedélyezett útvonal típus:",
"nokia.maps.navigationplayer.sncnavplayer.nogpsdesc":"Nincs GPS jel. Megadod a kiinduló pontot kézzel?",
"nokia.maps.pfw.action.changehighway.street":"change the freeway",
"nokia.maps.pfw.action.noaction.street":"folytasd",
"nokia.maps.pfw.spices.routesettingsspice.nopedmode1":"Hiba a gyalogos útvonalban",
"nokia.maps.pfw.spices.routesettingsspice.nopedmode2":"50km-nél hosszab útvonal nem engedélyezett gyalogos útvonalnak. Az útvonal mód autósra váltva.",
"places.Country120":"Lao Népi Demokratikus Köztársaság",
"places.Country121":"Latvia",
"places.Country122":"Libanon",
"places.Country123":"Lesotho",
"places.Country124":"Libéria",
"places.Country125":"Libyan Arab Jamahiriya",
"places.Country126":"Liechtenstein",
"places.Country127":"Litvánia",
"nokia.maps.pfw.spices.waypointspice.setadestination":"Uticél megadása",
"places.Country128":"Luxemburg",
"places.Country129":"Makao",
"nokia.maps.pfw.spices.sncwaypointspice.routeplanner":"Útvonal tervező",
"mapPlayer_4_settings_landmarks_txt_title":"3D tereptárgyak",
"places.Country130":"Macedónia",
"places.Country131":"Madagaszkár",
"settingTimeFormat24h":"24 órás",
"nokia.maps.pfw.spices.touchwaypointspice.searchforadestination":"Uticél keresése",
"places.Country132":"Malawi",
"mapPlayer_66_settings_donwloadPlugin_txt_termsAndConditions":"feltételek",
"places.Country133":"Malaysia",
"places.Country134":"Maldives",
"places.Country135":"Mali",
"addressHelp":"*-gal jelölt mező kitöltése kötelező",
"places.Country136":"Málta",
"places.Country137":"Marshall Szigetek",
"mapPlayer_46_mapControl_zoomControl_bookmark_street":"Utca",
"places.Country138":"Martinique",
"places.Country139":"Mauritánia",
"nokia.maps.pfw.turn.keepleft":"tarts balra",
"nokia.maps.pfw.spices.waypointspice.setstartpoint":"Kezdőpont beállítása",
"applicationName":"Térképek",
"nokia.maps.pfw.turn.roundabout1.street":"az első kijárat -",
"nokia.maps.pfw.ui.waypointlistitem.lookuptext":"GPS pozíciód meghatározása...",
"places.Country140":"Mauricius",
"places.Country141":"Mayotte",
"places.Country142":"Mexikó",
"nokia.maps.pfw.action.enterhighway":"hajts fel az autópályára",
"places.Country143":"Micronézia",
"nokia.maps.navigationplayer.sncnavplayer.lblnavfrom":"Navigálás innen:",
"places.Country144":"Moldova",
"places.Country145":"Monakó",
"mapPlayer_3_settings_nightMode_txt_body":"Éjszakai nézet. Az éjszakai nézet biztosítja, hogy a Térképeket könnyen használhasd olyankor, amikor nincs vagy kevés a fény azáltal, hogy a térképszinek megváltoznak, így jobban láthatóak a sötétben.",
"places.Country146":"Mongólia",
"places.Country147":"Montenegró",
"places.Country148":"Montserrat",
"mapPlayer_51_mapControl_minimap_toolTip_collapse":"Minimap bezárása",
"nokia.maps.navigationplayer.sncnavplayer.nogpstitle":"Nincs GPS jel",
"places.Country149":"Marokkó",
"nokia.maps.pfw.action.noaction":"tovább",
"settingMeasuringUnits":"Mértékegység",
"nokia.maps.pfw.action.uturn.street":"fordulj U-ban -",
"nokia.maps.navigationplayer.sncnavplayer.title":"Útvonal tervezés",
"places.Country150":"Mozambik",
"places.Country151":"Myanmar",
"places.Country152":"Namíbia",
"places.Country153":"Nauru",
"mapPlayer_64_buttonsArray_mapview_checkbox_labels":"Cimkék",
"nokia.maps.pfw.ui.blockersettings.btnclose":"Bezár",
"places.Country154":"Nepál",
"places.Country155":"Hollandia",
"places.Country156":"Holland Antillák",
"positionNotAvailable":"Pozíció nem elérhető",
"places.Country157":"New Caledonia",
"places.Country158":"Újzéland",
"mapPlayer_60_weather_units_txt_fahrenheit":"°F",
"places.Country159":"Nikaragua",
"nokia.maps.pfw.spices.touchwaypointspice.search":"Keresés",
"places.category10":"Közigazgatási Területek és Épületek",
"places.category11":"Természeti és Földrajzi",
"nokia.maps.pfw.turn.quiteleft.street":"fordulj balra -",
"places.Country160":"Niger",
"places.Country161":"Nigéria",
"places.Country162":"Niue",
"places.Country163":"Norfolk Szigetek",
"nokia.maps.pfw.ui.waypointlistitem.gpsposition":"GPS pozíciód",
"places.Country164":"Észak-Mariana Szigetek",
"places.Country165":"Norvégia",
"places.Country166":"Oman",
"places.Country167":"Pakisztán",
"places.Country168":"Palau",
"settingTimeFormat":"Idő formátum",
"places.Country169":"Palesztínia",
"nokia.maps.routingmaplet.no":"Nem",
"mapPlayer_2_settings_nightMode_txt_title":"Éjszakai mód",
"routeTo":"Útvonal ide:",
"nokia.maps.pfw.turn.keepleft.street":"tarts balra -",
"errorMsgCategoryTerm":"Ebben a kategóriában nincs elem, amely megfelelne a keresési feltételnek %term.",
"places.Country170":"Panama",
"network_error":"A szolgáltatás nem elérhető. Ellenőrizd az internet kapcsolatot.",
"places.Country171":"Pápua Új Guinea",
"nokia.maps.pfw.ui.blockersettings.btnblock":"Akadály",
"places.Country172":"Paragvai",
"places.Country173":"Peru",
"places.Country174":"Philippines",
"places.Country175":"Pitcairn",
"places.Country176":"Lengyelország",
"places.Country177":"Portugália",
"places.Country178":"Puerto Rico",
"places.Country179":"Qatar",
"settingsUCASE":"Beállítások",
"showOnList":"A listán mutatva",
"nokia.maps.pfw.spices.routesettingsspice.routetype":"Útvonal típusa",
"mapPlayer_1_settings_header_txt":"Ovi Maps Testreszabása",
"mapPlayer_6_settings_mapLanguage_txt_title":"Térképek a saját nyelveden",
"settings":"beállítások",
"nokia.maps.pfw.ui.blockersettings.motorails":"Motorvonatok",
"nokia.maps.pfw.ui.transportationmodesettings.lbltransportation":"Szállítás:",
"places.Country180":"Egyesítés",
"places.Country181":"Románia",
"places.Country182":"Orosz föderáció",
"nokia.maps.pfw.turn.return":"vissza",
"places.Country183":"Ruanda",
"places.Country184":"Saint Barthélemy",
"places.Country185":"Saint Helena",
"places.Country186":"Saint Kitts and Nevis",
"mapPlayer_54_searchBox_searchButton_toolTip":"Keresés indítása",
"places.Country187":"Saint Lucia",
"places.Country188":"Saint Martin (Francia part)",
"places.Country189":"Saint Pierre and Miquelon",
"nokia.maps.pfw.maneuver.totaldistance":"Összesen:",
"nokia.maps.navigationplayer.sncnavplayer.lblnavto":"Navigálás ide",
"showMoreResults":"Továbbiak mutatása",
"nokia.maps.pfw.spices.routesettingsspice.dirtroads":"Nem burkolt utak",
"detectingPosition":"Helyzeted meghatározása...",
"nokia.maps.navigationplayer.sncnavplayer.btnviewwp":"Közbeeső helyek mutatása",
"places.Country190":"Saint Vincent and the Grenadines",
"places.Country191":"Samoa",
"places.Country192":"San Marino",
"places.Country193":"Sao Tome and Principe",
"nokia.maps.pfw.spices.waypointspice.adddestination":"Uticél hozzáadása",
"places.Country194":"Szaudarábia",
"places.Country195":"Szenegál",
"places.Country196":"Szerbia",
"places.Country197":"Seychelles",
"places.Country198":"Sierra Leone",
"mapPlayer_65_settings_donwloadPlugin_txt_termsAndConditions":"Elfogadom a",
"places.Country199":"Szingapúr",
"mapPlayer_26_mapControl_scale_txt_kilometres":"km",
"nokia.maps.pfw.spices.routeinfospice.routeinfo":"Útvonal:",
"title":"Térképek Alkalmazás",
"nokia.maps.pfw.ui.routetypesettings.street":"Utca",
"mapPlayer_43_mapControl_zoomControl_bookmark_country":"Ország",
"about.label1":"Névjegy",
"nokia.maps.pfw.turn.heavyright.street":"fordulj élesen jobbra -",
"about.label2":"Jogi nyilatkozat",
"about.label3":"A Térképek szolgáltatás használata vagy tartalmak letöltése nagy mértékben megnövelheti az adatforgalmat a szolgáltató hálózatában. Az alkalmazás által szolgáltatott információk pontatlanok lehetnek és esetleg nem teljesek. A Térképek alkalmazás kereskedelmi célokra nem használható. Az alkalmazás használata nem javasolt autó vagy motor vezetése közben.",
"about.label4":"Lásd a Használati feltételeket és a Végfelhasználói szerződést.",
"about.label5":"Feltételek",
"publishingOff":"Publishing is off",
"friends":"Barátok",
"nokia.maps.pfw.turn.keepmiddle.street":"hajts a középső sávban",
"webAppTitle":"Nokia Térképek Teszt Alkalmazás",
"nokia.maps.pfw.spices.touchwaypointspice.route":"Útvonal:",
"nokia.maps.pfw.spices.touchwaypointspice.routesettings":"Útvonal beállítások",
"noResults":"Sajnos a keresés eredménytelen.",
"places.subcategory10":"Múzeum",
"places.subcategory11":"Vallásos helyek",
"places.subcategory12":"Repülőtér",
"places.subcategory13":"Vasútállomás",
"places.subcategory14":"Tömegközlekedés",
"places.subcategory15":"Komp kikötő",
"places.subcategory16":"Taxi állomás",
"places.subcategory17":"Hotel",
"places.subcategory18":"Motel",
"places.subcategory19":"Szálló",
"nokia.maps.pfw.unit.minute":"perc",
"nokia.maps.pfw.ui.touchroutesummary.route":"Útvonal:",
"serviceSwitcher":"Szolgáltatás váltása",
"mapPlayer_9_about_Ovi_link":"http://maps.ovi.com/services/?handshake",
"nokia.maps.pfw.turn.roundabout2.street":"a második kijáraton",
"addressSearch":"Keresés",
"nokia.maps.pfw.spices.sncwaypointspice.directions":"Irány",
"places.subcategory20":"Kemping",
"places.subcategory21":"Pavilon / 24/7 / Nyilvános illemhely",
"places.subcategory22":"Sétálóutca",
"places.subcategory23":"Áruház",
"places.subcategory24":"Étel és Ital",
"places.subcategory25":"Gyógyszertár",
"nokia.maps.pfw.spices.routeinfospice.calcprogress":"Útvonal tervezés...",
"places.subcategory26":"Electronika",
"places.subcategory27":"Barkács, Ház és Kert",
"places.subcategory28":"Könyvesbolt",
"places.subcategory29":"Ruházat és Divat",
"nokia.maps.pfw.spices.waypointspice.routelabeleft":"Útvonal",
"mapPlayer_41_mapControl_zoomControl_toolTip_plus":"Nagyítás",
"nokia.maps.pfw.action.passjunction":"hajts át a csomóponton",
"places.subcategory30":"Sport",
"places.subcategory31":"Bolt",
"nokia.maps.pfw.turn.heavyright":"fordulj élesen jobbra",
"nokia.maps.pfw.turn.roundabout12.street":"a 12. kijáraton",
"places.subcategory32":"ATM / Pénzváltó",
"places.subcategory33":"Rendőrség / Sürgősségi",
"places.subcategory34":"Postahivatal",
"mapPlayer_33_mapControl_panningControl_toolTip_moveLeft":"Move West",
"places.subcategory35":"Tourinform",
"places.subcategory36":"Üzemanyagtöltő állomás",
"places.subcategory37":"Autó kölcsönző",
"nokia.maps.pfw.turn.roundabout7.street":"a 7. kijáraton",
"places.subcategory38":"Autó kereskedő / Szerviz",
"settingMeasuringUnitsImperial":"Angol mértékegységek",
"nokia.maps.pfw.action.enterhighwayfromright":"hajts fel az autópályára jobbról",
"places.subcategory39":"Utazási iroda",
"nokia.maps.pfw.spices.touchwaypointspice.directions":"Irány",
"nokia.maps.pfw.ui.settingsmenuoption.btncancel":"Mégse",
"no":"Nem",
"errorMsgTerm":"Nincs elem, ami megfelelne a keresési feltételnek %term.",
"nokia.maps.pfw.ui.blockersettings.dirtroads":"Burkolatlan út",
"places.subcategory40":"Kommunikáció / Média",
"places.subcategory41":"Üzlet / Ipar",
"places.subcategory42":"Szolgáltatás",
"nokia.maps.pfw.spices.routesettingsspice.ferries":"Kompok",
"places.subcategory43":"Kórház vagy Egészségközpont",
"places.subcategory44":"Kormányzati vagy Közösségi épület",
"places.subcategory45":"Oktatási intézmény",
"places.subcategory46":"Könyvtár",
"previousTitle":"Előző",
"errorMsgCategory":"Nincs elem ebben a kategóriában",
"places.subcategory47":"Kiállítás és Rendezvény központ",
"mapPlayer_29_mapControl_scale_toolTip_switchToImperial":"Átváltás angol mértékegységre",
"places.subcategory48":"Parkolóház",
"places.subcategory49":"Sport központ / Találkozóhely",
"mapPlayer_52_mapControls_copyright":"Nokia © 2009 All rights reserved",
"ok":"Ok",
"yourCurrentPosition":"Jelenlegi helyzeted",
"mapMe":"Map me",
"deny":"Elutasít",
"nokia.maps.navigationplayer.sncnavplayer.btnno":"Nem",
"nokia.maps.routingmaplet.routingerror.noroutefound.disabledroadtypes":"Az útvonal elkészült, de olyan utak is szerepelnek benne, melyek használatát letiltottad. Akarod ezeket engedélyezni?",
"nokia.maps.pfw.spices.waypointspice.setstartposition":"Kiindulási pont beállítása",
"nokia.maps.pfw.ui.routetypesettings.fastest":"Leggyorsabb",
"nokia.maps.pfw.ui.touchroutesummary.ridenow":"Ride now",
"places.subcategory50":"Facility",
"places.subcategory51":"Pihenés",
"places.subcategory52":"Vidámpark vagy Szabadidő park",
"places.AMBIENCE":"Környezet",
"places.subcategory53":"Közigazgatási körzet",
"places.subcategory54":"Nagyváros, város vagy falu",
"places.subcategory55":"Szabadtéri terület / Komplexum",
"places.subcategory56":"Épület",
"nokia.maps.pfw.action.stopover":"elértél egy közbeeső uticélt",
"places.subcategory57":"Víztömeg",
"places.subcategory58":"Hegy vagy hegység",
"places.subcategory59":"Tenger alatti látványosság",
"defaultSearchTerm":"pl. egy cím, üzlet vagy hely név",
"mapPlayer_18_buttonsArray_mapview_buttonLabel_satellite":"Műhold",
"nokia.maps.pfw.ui.blockersettings.ferries":"Kompok",
"nokia.maps.pfw.turn.lightright.street":"fordulj kissé jobbra -",
"places.subcategory60":"Erdő, puszta vagy egyéb növényzet",
"call":"Hívás",
"mapPlayer_62_commons_status_buttonLabel_on":"BE",
"submit":"Submit",
"mapPlayer_10_about_mobile_txt":"Ellenőrizés hogy az Ovi Maps elérhető-e a készülékedre",
"places.OVERALL":"Általános becslés",
"QTN_COMMAND_DETAILS":"Adatok mutatása",
"backToList":"Vissza a listához",
"favourites":"Kedvencek",
"nokia.maps.pfw.unit.hour":"ó",
"nokia.maps.pfw.ui.sncapplicationui.btncancel":"Mégse",
"nokia.maps.routingmaplet.routingerror.noroutefound.noendpoint":"Befejező pont nem található.",
"nokia.maps.pfw.ui.blockersettings.motorways":"Autópályák",
"sendSmsTo":"SMS küldése -",
"hideCategories":"Kategóriák elrejtése",
"nokia.maps.pfw.spices.waypointspice.setstopover":"Pihenő beállítása",
"mapPlayer_35_mapControl_tiltControl_toolTip_switchTo3d":"Átváltás 3D-re",
"nokia.maps.pfw.turn.noturn.street":"menj egyenesen előre-",
"settingTimeFormat12h":"12 órás",
"errorMsgAddress":"Add meg \"Street-address city country\" a cím kereséséhez.",
"loadingApplication":"Alkalmazás betöltése...",
"nokia.maps.pfw.action.stopover.street":"elértél egy közbeeső uticélt",
"retry":"Újra",
"nokia.maps.pfw.turn.lightleft.street":"fordulj kissé balra -",
"places.label1":"Map Me",
"places.label2":"Helyek keresése",
"places.label3":"pl. Párizs vagy Pizza",
"nokia.maps.pfw.ui.transportationmodesettings.captionbicycle":"Kerékpár",
"places.label4":"Eredmény:",
"places.label5":"Eredmények",
"nokia.maps.pfw.turn.roundabout3.street":"a 3. kijáraton -",
"places.label7":"Csatlakozás",
"places.label8":"Jelentés",
"showPreviousResults":"Előző eredmények mutatása",
"places.label9":"Rang",
"about.longTxt":"<p>Satellite Imagemap &copy; 2002<br/> Planetary Visions Ltd planetaryvisions.com<br/></p><p>Imagery &copy; 2008 DigitalGlobe, Inc.<br/>&copy; Crown Copyright 100048088</p><p>Aprobado por el Instituto Geográfico Militar. <br/>Número de Expediente GG081531/Sept 5 2008</p><p>SRTM V4, 2008, CIAT<br/>srtm.csi.cgiar.org</p>",
"nokia.maps.routingmaplet.routingerror.cannotdopedestrian":"50km-nél hosszabb gyalogos útvonal nem tervezhető. Átváltasz autós módra?",
"nokia.maps.pfw.spices.touchwaypointspice.setfromsearch":"Beállítás keresésből",
"nokia.maps.pfw.ui.waypointlistitem.lookupdesc":"Kattints ide, ha a kiinduló pontot kézzel akarod beállítani.",
"nokia.maps.pfw.spices.touchdirectionspice.defineyourwaypoints":"Közbeeseő uticélok beállítása",
"breadCrumbHome":"Otthon",
"mapPlayer_5_settings_landmarks_txt_body":"A színes 3D-s nézet közelebb hozza a világot. Nézd meg madártávlatból a Tower hidat, repüld körbe az operát Sidey-ben vagy gyönyörködj az Eiffel tornyban. A világjárás még soha nem volt ennyire egyszerű.",
"nokia.maps.pfw.spices.waypointspice.addstopover":"Pihenő közbeiktatása",
"nokia.maps.pfw.action.enterhighwayfromright.street":"hajts fel a(z) {0} autópályára jobbról",
"places.DECOR":"Décor",
"myProfile":"Profilom",
"nokia.maps.pfw.turn.roundabout8.street":"a 8. kijáraton -",
"cancel":"Mégse",
"places.subcategory1":"Étterem",
"places.subcategory2":"Snack-bar / Gyorsétterem",
"places.subcategory3":"Bar / Pub",
"places.subcategory4":"Kávé / Tea",
"nokia.maps.pfw.action.enterhighwayfromleft.street":"hajts fel a(z) {0} autópályára balról",
"places.subcategory5":"Tánc vagy Éjszakai Klub",
"mapPlayer_58_weather_weatherButton_toolTip_off":"Időjárás előrejelzés a közelben",
"places.subcategory6":"Filmszínház",
"places.subcategory7":"Színház, Zene és Kultúra",
"places.subcategory8":"Casino",
"places.subcategory9":"Látványosság",
"nokia.maps.pfw.spices.routesettingsspice.tollroads":"Fizető utak",
"mapPlayer_23_mapControl_scale_txt_feet":"láb",
"mapPlayer_37_mapControl_tiltControl_buttonLabel_3d":"3D",
"nokia.maps.pfw.unit.mile":"mi",
"nokia.maps.pfw.ui.routetypesettings.straightline":"Egyenes vonal",
"nokia.maps.pfw.spices.waypointspice.setdestination":"Uticél beállítása",
"places.FOOD":"Étel",
"nokia.maps.pfw.unit.yard":"yard",
"nokia.maps.pfw.turn.quiteleft":"fordulj balra",
"about.txt1":"Ovi Maps 1.01",
"about.txt2":"www.nokia.com/maps/support",
"about.txt3":"maps.ovi.com",
"readTnC":"Általános Szerződési Feltételek",
"about.txt4":"&copy; 2008 NAVTEQ<br/>All Rights Reserved<br/>www.navteq.com",
"about.txt5":"&copy; 2008 NavInfo Co Ltd.<br/>All Rights Reserved<br/>www.nav2.com.cn",
"mapPlayer_27_mapControl_scale_toolTip_expand":"Vonalzó",
"nokia.maps.pfw.action.continuehighway.street":"haladj az autópályán",
"nokia.maps.pfw.spices.routesettingsspice.confirm":"OK",
"nokia.maps.pfw.spices.routesettingsspice.noroute1":"Nem található útvonal!",
"mapPlayer_40_mapControl_zoomControl_toolTip_minus":"Kicsinyítés",
"nokia.maps.pfw.spices.routesettingsspice.noroute2":"Ez az útvonal nem tervezhető e nélkül:",
"nokia.maps.pfw.spices.routesettingsspice.noroute3":"engedélyezve lesz.",
"nokia.maps.pfw.action.roundabout.street":"a körforgalomnál",
"downloading_data":"Adatok letöltése",
"currentPositionObjectLongitude":"-94.76",
"publishingOn":"Közzététel bekapcsolva",
"errorMsg":"Nincsenek elemek",
"nokia.maps.pfw.spices.routesettingsspice.close":"Bezár",
"nokia.maps.pfw.spices.touchdirectionspice.noroutedefinedyet":"Még nincs útvonal meghatározva!",
"mapPlayer_63_commons_status_buttonLabel_off":"KI",
"mapPlayer_55_weather_sectionTitle_txt_fiveDay":"Időjárás előrejelzés a következő 24 órára",
"nokia.maps.pfw.turn.lightleft":"fordulj enyhén balra",
"nokia.maps.pfw.action.changehighway":"change the freeway",
"places.SERVICE":"Szolgáltatás",
"nokia.maps.pfw.turn.keepright.street":"tarts jobbra -",
"places.RANGE":"Hatótávolság",
"places.Country1":"Afganisztán",
"places.Country2":"Åland Szigetek",
"places.Country3":"Albánia",
"places.Country4":"Algéria",
"places.Country5":"American Samoa",
"places.category1":"Étel és Ital",
"places.Country6":"Andorra",
"nokia.maps.pfw.spices.touchwaypointspice.gpsposition":"GPS pozíció",
"places.category2":"Going Out",
"places.Country7":"Angola",
"places.category3":"Látványosság és Múzeum",
"settingMeasuringUnitsMetric":"Metrikus",
"places.Country8":"Anguilla",
"places.category4":"Közlekedés",
"places.Country9":"Antarctica",
"places.category5":"Szállás",
"places.category6":"Bevásárlás",
"nokia.maps.routingmaplet.routingerror.noroutefound.disabledoptions":"Nem található útvonal. Néhány beállítás (pl. autópályák letiltása) is okozhatja ezt. Engedélyezet az összes út típust?",
"places.category7":"Üzleti & Szolgáltatás",
"places.category8":"Facilities",
"places.category9":"Szabadidő",
"mapPlayer_13_settings_donwloadPlugin_toolTip":"Telepítsd a plug-in-t, hogy hozzáférj további lehetőségekhez",
"mapPlayer_34_mapControl_panningControl_toolTip_moveRight":"Move East",
"mapPlayer_42_mapControl_zoomControl_toolTip_slider":"Húzd a nagyításhoz",
"nokia.maps.pfw.action.junction":"a csomópontnál",
"nokia.maps.pfw.maneuver.joiner":"és",
"nokia.maps.pfw.spices.routesettingsspice.tunnels":"Alagutak",
"mapPlayer_24_mapControl_scale_txt_miles":"mi",
"findPlaces":"Helyek keresése",
"nokia.maps.pfw.spices.touchwaypointspice.waypoints":"Közbeeső uticélok",
"nokia.maps.pfw.turn.roundabout1":"az 1. kijáraton -",
"nokia.maps.pfw.turn.roundabout2":"a 2. kijáraton -",
"nokia.maps.pfw.turn.roundabout3":"a 3. kijáraton -",
"nokia.maps.pfw.turn.roundabout4":"a 4. kijáraton -",
"nokia.maps.pfw.turn.roundabout5":"az 5. kijáraton -",
"nokia.maps.pfw.turn.roundabout6":"a 6. kijáraton -",
"nokia.maps.pfw.turn.roundabout7":"a 7. kijáraton -",
"nokia.maps.pfw.turn.roundabout8":"a 8. kijáraton -",
"nokia.maps.pfw.turn.roundabout9":"a 9. kijáraton -",
"nokia.maps.pfw.unit.kilometer":"km",
"nokia.maps.routingmaplet.yes":"Igen",
"nokia.maps.routingmaplet.routingerror.editroutesettings":"Útvonal beállítások szerkesztése",
"nokia.maps.pfw.ui.blockersettings.tunnels":"Alagutak",
"nokia.maps.pfw.ui.blockersettings.tollroads":"Fizető utak",
"mapPlayer_48_mapControl_rotationControl_toolTip_alignToNorth":"Északhoz igazít",
"nokia.maps.pfw.unit.milesperhour":"mph",
"mapPlayer_44_mapControl_zoomControl_bookmark_state":"Állam",
"mapPlayer_64_settings_donwloadPlugin_txt_teaser":"Egyszerűen telepítsd az ingyenes extra plug-in-t, hogy ezeket a nagyszerű lehetőségeket elérhesd.",
"mapPlayer_47_mapControl_rotationControl_north":"É",
"nokia.maps.pfw.turn.roundabout4.street":"a 4. kijáraton -",
"nokia.maps.pfw.action.uturn":"fordulj U-ban -",
"nokia.maps.pfw.spices.routesettingsspice.btndone":"Rendben",
"mapPlayer_20_buttonsArray_mapview_toolTip":"Átváltás Térkép módra",
"places.Country200":"Szlovákia",
"places.Country201":"Szlovénia",
"mapPlayer_17_buttonsArray_mapview_buttonLabel_map":"Térkép nézet",
"importance":"Fontosság",
"places.Country202":"Solomon Szigetek",
"addressError":"Minden kötelező mezőt ki kell tölteni",
"places.Country203":"Szomália",
"places.Country204":"Dél-Afrika",
"places.Country205":"Dél Georgia és Dél Sandwich Szigetek",
"places.Country206":"Spanyolország",
"places.Country207":"Sri Lanka",
"places.Country208":"Szudán",
"byCategory":"Kategória szerint",
"places.Country209":"Suriname",
"nokia.maps.pfw.turn.heavyleft.street":"fordulj élesen balra -",
"nokia.maps.pfw.ui.routetypesettings.lblmain":"Útvonal típus:",
"nokia.maps.pfw.action.leavehighway.street":"hajts ki a(z) {1} kijáraton ehhez: {0}",
"nokia.maps.pfw.turn.roundabout9.street":"a 9. kijáraton -",
"places.Country210":"Svalbard and Jan Mayen",
"places.Country211":"Szváziföld",
"places.Country212":"Svédország",
"places.Country213":"Svájc",
"nokia.maps.pfw.spices.routesettingsspice.highways":"Autóutak",
"places.Country214":"Szíria",
"places.Country215":"Tajvan",
"places.Country216":"Tajikistan",
"places.Country217":"Tanzánia",
"places.Country218":"Thaiföld",
"nokia.maps.pfw.action.undefined.street":"utazás indítása",
"places.Country219":"Timor-Leste",
"mapPlayer_38_mapControl_tiltControl_buttonLabel_2d":"2D",
"nokia.maps.pfw.spices.touchdirectionspice.directions":"Útvonal",
"nokia.maps.pfw.action.ferry.street":"hajts fel a kompra",
"Ok":"OK",
"mapPlayer_32_mapControl_panningControl_toolTip_moveDown":"Move South",
"places.Country220":"Togo",
"places.Country221":"Tokelau",
"distance":"Távolság",
"places.Country222":"Tonga",
"places.Country223":"Trinidad és Tobagó",
"places.Country224":"Tunézia",
"places.Country225":"Törökország",
"places.Country226":"Türkmenisztán",
"places.Country227":"Turks and Caicos Islands",
"places.Country228":"Tuvalu",
"places.Country229":"Uganda",
"showCategories":"Szűrés kategória szerint",
"nextTitle":"Következő",
"mapPlayer_22_buttonsArray_traffic_toolTip_off":"Forgalom mutatása",
"search":"Keresés",
"QTN_POISEARCH_ITEM08_01":"3D tereptárgyak",
"nokia.maps.pfw.action.end.street":"megérkeztél az uticélhoz",
"places.Country230":"Ukrajna",
"places.Country231":"Egyesült Arab Emirátusok",
"places.Country232":"Egyesült Királyság",
"places.Country233":"Egyesült Államok",
"nokia.maps.pfw.spices.touchwaypointspice.drivenow":"Vezetés most",
"places.Country234":"United States Minor Outlying Islands",
"places.Country235":"Urugvaj",
"places.Country236":"Üzbegisztán",
"services":"Szolgáltatások",
"places.Country237":"Vanuatu",
"places.Country238":"Venezuela",
"places.Country239":"Vietnam",
"addressCity":"Város / Ir.sz. *",
"nokia.maps.pfw.spices.touchwaypointspice.setyourwaypoints":"Közbeeső uticél beállítása",
"places.Country240":"Virgin Islands, British",
"nokia.maps.pfw.action.continuehighway":"hajts az autópályán",
"places.Country241":"Virgin Islands, U.S.",
"places.Country242":"Wallis and Futuna",
"nokia.maps.navigationplayer.sncnavplayer.btnyes":"Igen",
"places.Country243":"Nyugat Szahara",
"nokia.maps.pfw.ui.routetypesettings.optimized":"Optimalizálva",
"places.Country244":"Yemen",
"nokia.maps.pfw.turn.quiteright":"fordulj jobbra",
"places.Country245":"Zambia",
"places.Country246":"Zimbabwe",
"settingsOf":"Beállítás - ",
"currentPositionObjectLatitude":"39.29",
"mapPlayer_12_settings_downloadPlugin_buttonLabel":"Ingyenes plugin telepítése",
"nokia.maps.pfw.spices.touchstarttrackingspice.btnstart":"Kövess",
"places.FACILITIES":"Facilities",
"errorBackEndUnavailable":"A kiszolgáló nem elérhető!\nAz alkalmazás nem indítható.\nA kellemetlenségért elnézést kérünk.\nPróbáld újra indítani az alkamazást pár perc múlva.",
"addressCountry":"Ország / Régió *",
"mapPlayer_59_weather_units_txt_centigrades":"°C",
"mapPlayer_31_mapControl_panningControl_toolTip_moveUp":"Move North",
"places.connectMenu1":"Mutasd a térképen",
"places.label10":"Több",
"places.connectMenu2":"Hívás",
"places.label11":"Vissza",
"places.connectMenu3":"Hely küldése ide:",
"places.label12":"Telefon",
"places.label13":"Osztályzat",
"places.label14":"Kategória>Alkategória",
"mapPlayer_67_settings_donwloadPlugin_link_termsAndConditions":"http://maps.ovi.com/services/terms-en.html",
"places.label15":"Osztályozd ezt a helyet",
"addressStreet":"Utca",
"places.label16":"Átlagos osztályzat",
"places.label17":"Osztályzatod:",
"places.label18":"Küld",
"places.label19":"Adj adatokat ha szeretnél ehhez:",
"places.label20":"Jelentsd ez a helyet",
"places.label21":"Miért jelented ezt a helyet?",
"places.label22":"Ez a hely már nem létezik többé",
"nokia.maps.pfw.spices.touchroutesummary.noroutelength":"--.--",
"places.label23":"Ez a hely kettőzött",
"places.label24":"Helytelen",
"places.label25":"Ez a hely rossz információkat tatalmaz",
"places.label26":"Ez a hely rossz helyen van",
"application":"Alkalmazás",
"places.label27":"Jelentésed elküldtük",
"places.label28":"Közreműködésed köszönjük!",
"places.label29":"Kérlek adj meg adatokat",
"nokia.maps.pfw.turn.keepmiddle":"maradj a középső sávban",
"nokia.maps.pfw.action.passjunction.street":"hajts át a csomóponton",
"places.Country10":"Antigua and Barbuda",
"places.Country11":"Argentina",
"places.Country12":"Armenia",
"mapPlayer_19_buttonsArray_mapview_buttonLabel_terrain":"Terep",
"places.Country13":"Aruba",
"places.label30":"Adj meg érvényes cím adatokat",
"places.Country14":"Ausztrália",
"mapPlayer_45_mapControl_zoomControl_bookmark_city":"Város",
"places.label31":"*-gal jelölt mezők kötelezőek",
"places.Country15":"Ausztria",
"nokia.maps.pfw.ui.transportationmodesettings.captionwalk":"Séta",
"places.label32":"Utca név*",
"places.Country16":"Azerbaijan",
"nokia.maps.pfw.ui.touchroutesummary.walknow":"Séta most",
"places.label33":"Szám",
"places.Country17":"Bahamák",
"places.label34":"Irányítószám",
"places.Country18":"Bahrain",
"places.label35":"Város*",
"places.Country19":"Banglades",
"places.label36":"Ország*",
"places.label37":"Válassz országot",
"places.label38":"Kezd el gépelni a lista szükítéséhez!",
"places.label39":"Spam",
"nokia.maps.pfw.turn.roundabout10.street":"a 10. kijáraton -",
"mapPlayer_14_settings_donwloadPlugin_txt_availability":"Available on Windows for Internet Explorer v6-7and Firefox v2.1-3; on Mac OsX 10.4-10.5 for Safari 3",
"nokia.maps.pfw.spices.sncwaypointspice.navigatenow":"Navigálás most",
"nokia.maps.pfw.turn.roundabout5.street":"az 5. kijáraton -",
"nokia.maps.pfw.spices.touchroutesummary.norouteduration":"--:--",
"nokia.maps.navigationplayer.sncnavplayer.btnaddtoroute":"Hozzáadás útvonalhoz",
"nokia.maps.pfw.spices.routesettingsspice.noroute21":"Nem található útvonal",
"nokia.maps.pfw.spices.routesettingsspice.noroute22":"Az útvonal nem tervezhető. Elképzelhető, hogy nem állnak rendelkezésre a szükséges térkép adatok.",
"nokia.maps.pfw.ui.routetypesettings.shortest":"Legrövidebb",
"nokia.maps.pfw.unit.second":"mp",
"places.Country20":"Barbados",
"places.Country21":"Belarus",
"places.Country22":"Belgium",
"places.Country23":"Belize",
"nokia.maps.routingmaplet.routingerror.noroutefound.noendpointcheckoptions":"A végpont nem elérhető. Néhány beállítás (pl. útvonalak tiltása) is okozhatja ezt.",
"places.label40":"Invades my privacy",
"places.Country24":"Benin",
"places.label41":"Szexuális vagy pornó tartalmak",
"places.Country25":"Bermuda",
"places.label42":"Gyűlölködő vagy erőszakos tartalom",
"places.Country26":"Bhutan",
"places.label43":"Egyéb ok",
"places.Country27":"Bolivia",
"places.label44":"Név",
"places.Country28":"Bosznia és Herzegovina",
"places.label45":"Kategória",
"places.Country29":"Botswana",
"places.label46":"Telefon 1",
"places.label47":"Telefon 2",
"places.label48":"Fax",
"places.label49":"Email",
"nokia.maps.pfw.action.leavehighway":"hajts le az autópályáról",
"nokia.maps.pfw.turn.heavyleft":"fordulj élesen balra -",
"nokia.maps.routingmaplet.routingerror.noroutefound":"Nem található útvonal.",
"mapPlayer_7_settings_mapLanguage_txt_body":"Soon you will be able to choose the language in which Maps is displayed.",
"places.Country30":"Bouvet Island",
"places.Country31":"Brazil",
"places.Country32":"British Indian Ocean Territory",
"places.Country33":"Brunei Darussalam",
"places.label50":"URL",
"places.Country34":"Bulgária",
"places.label51":"Válassz egy kategóriát",
"places.Country35":"Burkina Faso",
"places.Country36":"Burundi",
"places.Country37":"Cambodia",
"places.Country38":"Cameroon",
"places.Country39":"Kanada",
"mapPlayer_50_mapControl_minimap_toolTip_expand":"Minimap megnyitása",
"nokia.maps.pfw.turn.return.street":"vissza -",
"places.Country40":"Cape Verde",
"places.Country41":"Kajmán Szigetek",
"places.Country42":"Közép-Afrika",
"places.Country43":"Chad",
"places.Country44":"Chile",
"places.Country45":"Kína",
"places.Country46":"Karácsony Szigetek",
"places.Country47":"Cocos (Keeling) Szigetek",
"places.Country48":"Kolumbia",
"places.label65":"Utca név és szám",
"places.Country49":"Comoros",
"places.label66":"Kapcsolat adatok",
"places.label67":"Sajnálom! Jelentésed nem küldhető el.",
"places.label68":"Megpróbálod ismét elküldeni?",
"places.label69":"Igen",
"mapPlayer_57_weather_weatherButton_toolTip_on":"Időjárásjelentés megnyitása",
"nokia.maps.pfw.spices.waypointspice.deleteroute":"Útvonal törlése",
"nokia.maps.routingmaplet.routingerror.cannotdopedestrian.miles":"31 mérföldnél hosszabb gyalogos útvonal nem tervezhető. Átváltasz autós módra?",
"nokia.maps.pfw.turn.quiteright.street":"fordulj jobbra -",
"places.Country50":"Kongó",
"TnC":"A8z) %1 használatához el kell fogadnod a Felhasználói feltételeket",
"places.Country51":"Kongó",
"places.Country52":"Cook Szigetek",
"places.Country53":"Costa Rica",
"places.label70":"Mégse",
"places.Country54":"Côte d'Ivoire",
"places.label71":"A keresés eredménytelen.",
"places.Country55":"Kroácia",
"places.label72":"A kereséshez kezdj el gépelni...",
"places.Country56":"Kuba",
"places.label73":"Szavazatod köszönjük",
"places.Country57":"Ciprus",
"places.label74":"Nem, köszönöm!",
"nokia.maps.pfw.spices.webwaypointspice.totaldistandandtime":"Teljes távolság | Idő",
"places.Country58":"Cseh Köztársaság",
"places.label75":"Kérlek add meg a jó információkat",
"places.Country59":"Dánia",
"places.label76":"Keresés",
"mapPlayer_36_mapControl_tiltControl_toolTip_switchTo2d":"Váltás 2D-re",
"places.label77":"Kezd gépelni vagy kattints egy pédára lejebb",
"places.label78":"Keresés - ",
"places.label79":"közeli",
"loadingMaplet":"Alkalmazás betöltése",
"mapPlayer_30_mapControl_scale_toolTip_switchToMetric":"Átváltás metrikusra",
"showOnMap":"Mutasd a térképen",
"nokia.maps.pfw.ui.settingsmenuoption.btnselect":"Kiválaszt",
"yes":"Igen",
"nokia.maps.navigationplayer.sncnavplayer.routeinfo":"GPS keresése...",
"nokia.maps.pfw.spices.sncwaypointspice.map":"Térkép",
"places.Country60":"Djibouti",
"places.Country61":"Dominika",
"nokia.maps.pfw.ui.touchroutesummary.drivenow":"Vezetés most",
"places.Country62":"Dominikai Köztársaság",
"places.Country63":"Ecuador",
"places.label80":"Hiba történt keresés közben",
"places.Country64":"Egyiptom",
"places.label81":"Kívül a(z) %d osztályzaton",
"places.Country65":"El Salvador",
"places.label82":"Válassz egy alkategóriát",
"places.Country66":"Equatorial Guinea",
"places.Country67":"Eritrea",
"places.Country68":"Estonia",
"places.Country69":"Ethiopia",
"nokia.maps.pfw.spices.touchwaypointspice.setfrommap":"Beállítás térképről",
"nokia.maps.pfw.action.enterhighway.street":"hajts fel az autópályára",
"mapPlayer_25_mapControl_scale_txt_metres":"m",
"mapPlayer_53_searchBox_watermark_txt":"Írd be ide a helyet, amit keresel",
"nokia.maps.pfw.spices.touchwaypointspice.addanotherdestination":"Adj meg másik célpontot",
"places.Country70":"Falkland Szigetek (Malvinas)",
"places.Country71":"Fáraó Szigetek",
"places.Country72":"Fiji",
"QTN_SETS_NIGHTMODE":"Éjszakai mód",
"places.Country73":"Finország",
"places.Country74":"Franciaország",
"places.Country75":"French Guiana",
"places.Country76":"French Polynesia",
"addressNumber":"Szám",
"places.Country77":"French Southern Territories",
"places.Country78":"Gabon",
"places.Country79":"Gambia",
"clear":"Törlés",
"nokia.maps.routingmaplet.routingerror.noroutefound.nostartpoint":"Kezdőpont nem található.",
"mapPlayer_49_mapControl_rotationControl_toolTip_rotate":"Kattints és Húzd a forgatáshoz",
"mapPlayer_11_about_mobile_link":"http://www.nokia.com/betalabs/maps",
"nokia.maps.pfw.spices.routesettingsspice.btnnavigate":"Navigálás",
"mapPlayer_61_commons_close_toolTip":"Ablak bezárása",
"places.Country80":"Georgia",
"places.Country81":"Németország",
"places.Country82":"Ghána",
"places.Country83":"Gibraltár",
"nokia.maps.pfw.ui.blockersettings.btnunblock":"Feloldás",
"places.Country84":"Görögország",
"places.Country85":"Greenland",
"places.Country86":"Grenada",
"accept":"Elfogad",
"places.Country87":"Guadeloupe",
"places.Country88":"Guam",
"places.Country89":"Guatemala",
"loadingMapletFailed":"Hiba történt az alkalmazás megnyitása közben. Próbáld újra.",
"mapPlayer_16_buttonsArray_settings_toolTip":"Ovi Maps testreszabása",
"nokia.maps.pfw.spices.routesettingsspice.transmode":"Szállítási mód:",
"nokia.maps.pfw.action.junction.street":"a csomópontnál",
"nokia.maps.pfw.unit.meter":"m",
"currentZoomLevel":"517566",
"places.Country90":"Guernsey",
"places.Country91":"Guinea",
"mapPlayer_21_buttonsArray_traffic_toolTip_on":"Forgalom elrejtése",
"places.Country92":"Guinea-Bissau",
"places.Country93":"Guyana",
"test":"test-en",
"places.Country94":"Haiti",
"QTN_TEXT_MYPLACES_PLACES":"Helyek",
"places.Country95":"Heard Island and McDonald Islands",
"nokia.maps.pfw.turn.keepright":"tarts jobbra",
"places.Country96":"Holy See (Vatican City State)",
"nokia.maps.pfw.turn.noturn":"menj egyenesen előre",
"nokia.maps.pfw.turn.lightright":"fordulj kissé jobbra",
"places.Country97":"Hondurasz",
"places.Country98":"Hong Kong",
"places.Country99":"Magyarország",
"nokia.maps.pfw.spices.touchroutesummary.route":"Útvonal:",
"nokia.maps.pfw.spices.touchstarttrackingspice.btnstop":"Követés leállítása",
"nokia.maps.pfw.ui.sncapplicationui.btnselect":"Kiválasztás",
"nokia.maps.pfw.turn.roundabout11.street":"a 11. kijáraton -",
"mapPlayer_39_mapControl_tiltControl_toolTip_changeAngle":"3D látószög megváltoztatása",
"nokia.maps.pfw.turn.roundabout6.street":"a 6. kijáraton -",
"mapPlayer_28_mapControl_scale_toolTip_collapse":"Vonalzó minimalizálása",
"mapPlayer_56_weather_sectionTitle_txt_now":"Mai időjárás",
"options":"Beállítások",
"places.PRICE":"Ár",
"disclaimer":"A Térképek használata vagy tartalmak letöltése megnövelheti az adatforgalmat a szolgáltatódnál. Az alkalmazás által szolgáltatott információk pontatlanok lehetnek és etetenként nem teljesek. Az alkalmazás kereskedelmi célokra nem használható. A legfontosabb szempont a Maps használatakor a közlekedés biztonsága.",
"nokia.maps.pfw.ui.transportationmodesettings.captiondrive":"Vezetés",
"nokia.maps.pfw.ui.sncapplicationui.btnclose":"Bezár",
"nokia.maps.pfw.unit.kilometersperhour":"km/h",
"nokia.maps.pfw.action.ferry":"hajts fel a kompra",
"errorConnectionFailure":"A kereső szolgáltatás nem elérhető. Ellenőrizd, hogy a készülék csatlakozik e az internetre.",
"about_maps":"Ovi Maps névjegye",
"tips":"Tippek",
"three_d":"3D Nézet",
"nokia.maps.pfw.ui.waypointspice.searchstart":"Kiindulópont keresése",
"dashboard.getDirections":"Útbaejt",
"dashboard.clearMap":"Útvonal törlése",
"dashboard.findPlaces":"Keresés",
"searchInProgress":"Keresés folyamatban ...",
};
